@@ -1,13 +1,13 @@
 mod agent_conf;
 mod mod_conf;
-mod upload;
+mod zhiyan_proto;
 
 use serde_json::Value;
 use std::{thread, time::Duration};
 use tokio::runtime::Builder;
 use tonic::Request;
-use upload::upload_client::UploadClient;
-use upload::UploadRequest;
+use zhiyan_proto::upload_client::UploadClient;
+use zhiyan_proto::UploadRequest;
 
 pub fn send_request_json(json_value: Value) -> Result<(), ureq::Error> {
     let args: Vec<String> = std::env::args().collect();
@@ -42,7 +42,7 @@ pub fn mod_send_request_grpc(
             content: content.clone(),
         });
 
-        let response = client.mod_upload(request).await.unwrap();
+        let response = client.data_upload(request).await.unwrap();
         let upload_response = response.get_ref();
         println!(
             "Code:{:?}\tMessages{:?}",
@@ -52,22 +52,25 @@ pub fn mod_send_request_grpc(
     });
 }
 
-pub fn agent_send_request_grpc(name: String, datetime: i64, content: Vec<f32>) {
-    let args: Vec<String> = std::env::args().collect();
-    let conf_filename = &args[1];
-    let agent_conf = agent_conf::load_agent_conf(conf_filename).unwrap();
+pub fn agent_send_request_grpc(
+    name: String,
+    datetime: i64,
+    content: Vec<f32>,
+    conf_filename: String,
+) {
+    let agent_conf = agent_conf::load_agent_conf(&conf_filename.to_string()).unwrap();
 
     let run_time = Builder::new_multi_thread().enable_all().build().unwrap();
     run_time.spawn(async move {
         let mut client = UploadClient::connect(agent_conf.server_url).await.unwrap();
 
-        let request = Request::new(upload::UploadRequest {
+        let request = Request::new(UploadRequest {
             name: name.clone(),
             datetime: datetime.clone(),
             content: content.clone(),
         });
 
-        let response = client.mod_upload(request).await.unwrap();
+        let response = client.data_upload(request).await.unwrap();
         let upload_response = response.get_ref();
         println!("{:?}\n{:?}", upload_response.code, upload_response.message);
     });
